NAME
PerlBean::Attribute - contains bean attribute information
SYNOPSIS
None. This is an abstract class.
ABSTRACT
Abstract PerlBean attribute information
DESCRIPTION
PerlBean::Attribute abstract class for bean attribute information. Attribute access methods are implemented and code and documentation generation interface methods are defined.
CONSTRUCTOR
- new(OPT_HASH_REF)
-
Creates a new
PerlBean::Attributeobject.OPT_HASH_REFis a hash reference used to pass initialization options.OPT_HASH_REFis mandatory. On error an exceptionError::Simpleis thrown.Options for
OPT_HASH_REFmay include:attribute_name-
Passed to set_attribute_name(). Mandatory option.
default_value-
Passed to set_default_value().
exception_class-
Passed to set_exception_class(). Defaults to 'Error::Simple'.
mandatory-
Passed to set_mandatory(). Defaults to 0.
method_base-
Passed to set_method_base().
perl_bean-
Passed to set_perl_bean().
short_description-
Passed to set_short_description().
METHODS
- get_overloaded_attribute()
-
Searches superclass packages for an identically named
PerlBean::Attribute. If found it is returned otherwiseundefis returned. - get_package()
-
Returns the package name. The package name is obtained from the
PerlBeanto which thePerlBean::Attributebelongs. Or, if thePerlBean::Attributedoes not belong to aPerlBean,mainis returned. - get_package_us()
-
Calls
get_package()and replaces:+with C <_>. - type()
-
Determins and returns the type of the attribute. The type is either
BOOLEAN,SINGLEorMULTI. - write_default_value(FILEHANDLE)
-
This is an interface method. Writes
%DEFAULT_VALUEline for the attribute.FILEHANDLEis anIO::Handleobject. - write_doc_clauses(FILEHANDLE)
-
Writes documentation for the clauses to which the contents the contents of the attribute must adhere.
FILEHANDLEis anIO::Handleobject. - write_doc_inherit_methods(FILEHANDLE)
-
This is an interface method. Writes documentation for the access methods for the attribute in the case the attibute methods are inherited.
FILEHANDLEis anIO::Handleobject. - write_doc_init(FILEHANDLE)
-
This is an interface method. Writes documentation for
_initialize()for the attribute.FILEHANDLEis anIO::Handleobject. - write_doc_methods(FILEHANDLE)
-
This is an interface method. Writes documentation for the access methods for the attribute.
FILEHANDLEis anIO::Handleobject. - write_methods(FILEHANDLE)
-
This is an interface method. Writes the access methods for the attribute.
FILEHANDLEis anIO::Handleobject. - write_opt_init(FILEHANDLE)
-
This is an interface method. Writes
_initialize()option parsing code for the attribute.FILEHANDLEis anIO::Handleobject. - set_attribute_name(VALUE)
-
Set attribute's name.
VALUEis the value.VALUEmay not beundef. On error an exceptionError::Simpleis thrown. - get_attribute_name()
-
Returns attribute's name.
- set_default_value(VALUE)
-
Set attribute's default value.
VALUEis the value. On error an exceptionError::Simpleis thrown. - get_default_value()
-
Returns attribute's default value.
- set_exception_class(VALUE)
-
Set the class to throw when an exception occurs.
VALUEis the value. Default value at initialization is'Error::Simple'.VALUEmay not beundef. On error an exceptionError::Simpleis thrown. - get_exception_class()
-
Returns the class to throw when an exception occurs.
- set_mandatory(VALUE)
-
State that the attribute is mandatory for construction.
VALUEis the value. Default value at initialization is0. On error an exceptionError::Simpleis thrown. - is_mandatory()
-
Returns whether the attribute is mandatory for construction or not.
- set_method_base(VALUE)
-
Set the method base name.
VALUEis the value. On error an exceptionError::Simpleis thrown. - get_method_base()
-
Returns the method base name.
- set_perl_bean(VALUE)
-
Set the PerlBean to which this attribute belongs.
VALUEis the value. On error an exceptionError::Simpleis thrown. - get_perl_bean()
-
Returns the PerlBean to which this attribute belongs.
- set_short_description(VALUE)
-
Set the attribute description.
VALUEis the value. On error an exceptionError::Simpleis thrown. - get_short_description()
-
Returns the attribute description.
SEE ALSO
PerlBean, PerlBean::Attribute::Boolean, PerlBean::Attribute::Factory, PerlBean::Attribute::Multi, PerlBean::Attribute::Multi::Ordered, PerlBean::Attribute::Multi::Unique, PerlBean::Attribute::Multi::Unique::Associative, PerlBean::Attribute::Multi::Unique::Associative::MethodKey, PerlBean::Attribute::Multi::Unique::Ordered, PerlBean::Attribute::Single, PerlBean::Collection, PerlBean::Method, PerlBean::Method::Constructor, PerlBean::Style
BUGS
None known (yet.)
HISTORY
First development: November 2002
AUTHOR
Vincenzo Zocca
COPYRIGHT
Copyright 2002, 2003 by Vincenzo Zocca
LICENSE
This file is part of the PerlBean module hierarchy for Perl by Vincenzo Zocca.
The PerlBean module hierarchy is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
The PerlBean module hierarchy is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with the PerlBean module hierarchy; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA